/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Optimoz Tweaks.
 *
 * The Initial Developer of the Original Code is Jens Bannmann.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s) (alphabetical order):
 *  Jens Bannmann <jens.b@web.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var mtPrefSidebarSensitivity;
var mtPrefSidebarDelay;

var mtSidebarActive;

var mtLeavingSidebar = false;
var mtWindowHasFocus = true;
var mtMouseDown = false;
var mtSidebarTimeout = null;
var mtMousePos = "";
var mtMouseSaved = "";
var mtSidebarBox = document.getElementById("sidebar-box");

var mtSBWrapper_Firebird = {
  lastSidebar: "",

  init: function() {
    this.lastSidebar = mtGetPref("sidebar.last", "Char", "viewBookmarksSidebar");
  },

  isVisible: function() {
    return !mtSidebarBox.getAttribute("hidden");
  },

  toggle: function() {
    if (!this.isVisible()) {
      toggleSidebar(this.lastSidebar);
    } else {
      toggleSidebar();
      mtPrefBranch.setCharPref("sidebar.last", this.lastSidebar);
    }
  },
  
  onPrepareHide: function() {
    this.lastSidebar = mtSidebarBox.getAttribute("sidebarcommand");
  }
}
var mtSBWrapper_Seamonkey = {
  init: function() {},

  isVisible: function() {
    return !sidebar_is_hidden();
  },

  toggle: function() {
    SidebarShowHide();
  },
  
  onPrepareHide: function() {}
}

var mtSidebar = mtIsFirebird ? mtSBWrapper_Firebird : mtSBWrapper_Seamonkey;


function mtInitSidebar() {
  mtPrefSidebarSensitivity = mtGetPref("sidebar.sensitivity", "Int", 3, 0, 50);
  mtPrefSidebarDelay = mtGetPref("sidebar.delay", "Int", 300, 0, 5000);
  mtSidebar.init();

  if (mtGetPref("sidebar.enabled", "Bool", true)) {
    mtAddSidebarListeners();
    mtSidebarActive = true;
  } else if (mtSidebarActive) {
    mtRemoveSidebarListeners();
    mtSidebarActive = false;
  }
}

function mtAddSidebarListeners() {
  getBrowser().addEventListener("mousemove", mtToggleSidebar, true);
  mtSidebarBox.addEventListener("mouseover", mtPrepareHideSidebar, true);
  document.getElementById("sidebar-splitter").addEventListener("click", mtPreventHiding, true);
  document.getElementById("navigator-toolbox").addEventListener("mouseover", mtPreventHiding, true);
  window.addEventListener("mousedown", function() { mtMouseDown = true; }, true);
  window.addEventListener("mouseup", function() { mtMouseDown = false; }, true);
  window.addEventListener("blur", function () { mtWindowHasFocus = false; }, true);
  window.addEventListener("focus", function () { mtWindowHasFocus = true; }, true);
}

function mtRemoveSidebarListeners() {
  getBrowser().removeEventListener("mousemove", mtToggleSidebar, true);
  mtSidebarBox.removeEventListener("mouseover", mtPrepareHideSidebar, true);
  document.getElementById("sidebar-splitter").removeEventListener("click", mtPreventHiding, true);
  document.getElementById("navigator-toolbox").removeEventListener("mouseover", mtPreventHiding, true);
}

function mtToggleSidebar(e) {
  mtMousePos = e.clientX + "," + e.clientY;
  if (mtWindowHasFocus && document.getElementById("print-preview-toolbar") == null) {
    if (mtLeavingSidebar) {
      if (mtSidebar.isVisible()) { mtSidebar.toggle(); }
      mtLeavingSidebar = false;
    } else if (e.clientX <= mtPrefSidebarSensitivity && e.clientY > 50 && !mtSidebar.isVisible()) {
      window.clearTimeout(mtSidebarTimeout);
      mtSidebarTimeout = window.setTimeout(mtDelayedShowSidebar, mtPrefSidebarDelay);
      mtMouseSaved = mtMousePos;
    }
    if (e.pageX > mtPrefSidebarSensitivity) { mtLeavingSidebar = false; }
  }
}

function mtDelayedShowSidebar() {
  if (mtMouseSaved == mtMousePos && mtWindowHasFocus && !mtMouseDown) {
    mtSidebar.toggle();
    mtLeavingSidebar = true;
  }
}

function mtPrepareHideSidebar(e) {
  if (mtWindowHasFocus && !mtMouseDown) {
    mtLeavingSidebar = true;
    mtSidebar.onPrepareHide();
  }
}

function mtPreventHiding(e) {
  if (mtWindowHasFocus) {
    mtLeavingSidebar = false;
  }
}
